@@ -9,19 +9,19 @@ class InvalidFormatError(Exception):
         errorFile -- file that is not in the correct format.
         message -- optional user overridden error message to display.
     """
-
     def __init__(
         self,
         error_file,
-        message="The provided file has an invalid format. Please use files in the .nii, "
-        ".nii.gz format.",
+        message="The provided file has an invalid format. Please use files "
+                "in the .nii, .nii.gz format.",
     ):
         self.error_file = error_file
         self.message = message
         super().__init__(self.message)
 
     def __str__(self):
-        return f"{self.message} The error was caused by the file {self.error_file}."
+        return f"{self.message}" \
+               f" The error was caused by the file {self.error_file}."
 
 
 class InvalidSizeError(Exception):
@@ -32,9 +32,9 @@ class InvalidSizeError(Exception):
         * size -- size of the input image
         * message -- optional user defined error message
     """
-
     def __init__(
-        self, shape=(182, 218, 182), message="The provided file has a wrong shape."
+        self, shape=(182, 218, 182),
+            message="The provided file has a wrong shape."
     ):
         self.message = message
         self.shape = shape
@@ -48,12 +48,11 @@ class InvalidSizeError(Exception):
 class CheckPath:
     """Decorator to check if a path exists.
 
-    In order to run the function decorated the path provided to the function has to exists, otehrwise an error is
-    raised.
+    In order to run the function decorated the path provided to the function
+    has to exists, otherwise an error is raised.
 
     :raises FileNotFoundError:
     """
-
     def __init__(self, function):
         self.function = function
 
@@ -66,11 +65,11 @@ class CheckPath:
 class CheckExtension:
     """Decorator to check the file extension of the input scan.
 
-    Extension of the imaging scan has to be in NIfTI format (compressed or not) in order to run the function.
+    Extension of the imaging scan has to be in NIfTI format (compressed or not)
+     in order to run the function.
 
     :raises InvalidFormatError:
     """
-
     def __init__(self, function):
         self.function = function
 
@@ -84,11 +83,11 @@ class CheckExtension:
 class CheckShape:
     """Decorator to check the correct matrix shape of the imaging scan.
 
-    Shape of the matrix has to be 182x218x182 in order to run the function, otherwise raises and error.
+    Shape of the matrix has to be 182x218x182 in order to run the function,
+    otherwise raises and error.
 
     :raises InvalidSizeError:
     """
-
     def __init__(self, function):
         self.function = function
 
@@ -101,11 +100,11 @@ class CheckShape:
 class CheckVariance:
     """Decorator to check that the variance is in the correct range of values.
 
-    Target variance has to be in the range 0.0-1.0 (equivalent to 0-100%) in order to run the function.
+    Target variance has to be in the range 0.0-1.0 (equivalent to 0-100%) in
+    order to run the function.
 
     :raises ValueError:
     """
-
     def __init__(self, function):
         self.function = function
 
