@@ -58,7 +58,7 @@ def extract_average(imaging_matrix):
     ).get_fdata()
     data = np.zeros(n_regions)
     for i in range(1, n_regions + 1):
-        data[i - 1] = np.mean(imaging_matrix[np.where(atlas_data == i)])
+        data[i - 1] = np.nanmean(imaging_matrix[np.where(atlas_data == i)])
     logger.debug("Extracted values are: \n%s", data)
     return np.array(data)
 
@@ -98,7 +98,9 @@ def load_gene_labels():
     genes_labels_path = (
         Path(__file__).resolve().parent / "data" / "gene_expression_labels.txt"
     )
-    return pd.read_fwf(genes_labels_path, header=None).to_numpy()
+    # return pd.read_fwf(genes_labels_path, header=None).to_numpy()
+    return np.loadtxt(str(genes_labels_path), dtype="U",
+                      delimiter="\n").reshape(-1, 1)
 
 
 def get_geneset(gene_set: str):
